#
# spec file
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


#
%define modname odfpy
%define binaries csv2ods mailodf odf2mht odf2xhtml odf2xml odfimgimport odflint odfmeta odfoutline odfuserfield xml2odf
%{?sle15_python_module_pythons}
Name:           python-%{modname}
Version:        1.4.2
Release:        2.9
Summary:        Python API and tools to manipulate OpenDocument files
License:        Apache-2.0 OR GPL-2.0-or-later
Group:          Development/Languages/Python
URL:            https://github.com/eea/odfpy
Source:         https://github.com/eea/odfpy/archive/refs/tags/release-%{version}.tar.gz
BuildRequires:  %{python_module defusedxml}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-defusedxml
Requires(post): update-alternatives
Requires(postun):update-alternatives
BuildArch:      noarch
%python_subpackages

%description
Odfpy is a library to read and write OpenDocument v. 1.1 files.
The main focus has been to prevent the programmer from creating invalid
documents. It has checks that raise an exception if the programmer adds
an invalid element, adds an attribute unknown to the grammar, forgets to
add a required attribute or adds text to an element that doesn't allow it.

These checks and the API itself were generated from the RelaxNG
schema, and then hand-edited. Therefore the API is complete and can
handle all ODF constructions.

In addition to the API, there are a few scripts:

- csv2odf - Create OpenDocument spreadsheet from comma separated values
- mailodf - Email ODF file as HTML archive
- odf2xhtml - Convert ODF to (X)HTML
- odf2mht - Convert ODF to HTML archive
- odf2xml - Create OpenDocument XML file from OD? package
- odfimgimport - Import external images
- odflint - Check ODF file for problems
- odfmeta - List or change the metadata of an ODF file
- odfoutline - Show outline of OpenDocument
- odfuserfield - List or change the user-field declarations in an ODF file
- xml2odf - Create OD? package from OpenDocument in XML form

Visit https://github.com/eea/odfpy for documentation and examples.

%prep
%setup -q -n %{modname}-release-%{version}
sed -i "1d" odf/{userfield,odf2xhtml,manifest,element,elementtypes,load,odfmanifest,thumbnail}.py # Fix non-executable scripts

%build
%python_build

%install
%python_install
for b in %{binaries}; do
  %python_clone -a %{buildroot}%{_mandir}/man1/$b.1
  %python_clone -a %{buildroot}%{_bindir}/$b
done
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%post
for b in %{binaries}; do
  %python_install_alternative $b $b.1
done

%postun
for b in %{binaries}; do
  %python_uninstall_alternative $b
done

%files %{python_files}
%license APACHE-LICENSE-2.0.txt GPL-LICENSE-2.txt
%python_alternative %{_bindir}/csv2ods
%python_alternative %{_bindir}/mailodf
%python_alternative %{_bindir}/odf2mht
%python_alternative %{_bindir}/odf2xhtml
%python_alternative %{_bindir}/odf2xml
%python_alternative %{_bindir}/odfimgimport
%python_alternative %{_bindir}/odflint
%python_alternative %{_bindir}/odfmeta
%python_alternative %{_bindir}/odfoutline
%python_alternative %{_bindir}/odfuserfield
%python_alternative %{_bindir}/xml2odf
%python_alternative %{_mandir}/man1/csv2ods.1%{ext_man}
%python_alternative %{_mandir}/man1/mailodf.1%{ext_man}
%python_alternative %{_mandir}/man1/odf2mht.1%{ext_man}
%python_alternative %{_mandir}/man1/odf2xhtml.1%{ext_man}
%python_alternative %{_mandir}/man1/odf2xml.1%{ext_man}
%python_alternative %{_mandir}/man1/odfimgimport.1%{ext_man}
%python_alternative %{_mandir}/man1/odflint.1%{ext_man}
%python_alternative %{_mandir}/man1/odfmeta.1%{ext_man}
%python_alternative %{_mandir}/man1/odfoutline.1%{ext_man}
%python_alternative %{_mandir}/man1/odfuserfield.1%{ext_man}
%python_alternative %{_mandir}/man1/xml2odf.1%{ext_man}
%{python_sitelib}/odf
%{python_sitelib}/%{modname}*

%changelog
* Wed Dec 20 2023 Michal Suchanek <msuchanek@suse.com>
- Make installable for Python 3.11 on Leap
* Wed Jan  4 2023 Dirk Müller <dmueller@suse.com>
- update to 1.4.2:
  * Add scale-to-X and scale-to-Y attributes to page-layout properties
  * Add Support for Linux on power
  * Update datatable.py
  * Fix bug in __replaceGenerator()
* Sun Oct  4 2020 John Vandenberg <jayvdb@gmail.com>
- Change license from GPL-2.0-or-later AND Apache-2.0 to
  GPL-2.0-or-later OR Apache-2.0
* Thu May 21 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
* Fri Mar 27 2020 pgajdos@suse.com
- version update to 1.4.1
  * no upstream changelog found
* Fri Feb 22 2019 John Vandenberg <jayvdb@gmail.com>
- Update to v1.4.0
  * Use defusedxml, which guards against various XML vulnerabilities
  * Fix odf/opendocument.py toXml needs codecs import
  * Add tests for various XML vulnerabilities
  * Add metadata for Python 3.7 support
- Replace dead url with https://github.com/eea/odfpy
* Wed Aug 29 2018 tchvatal@suse.com
- Make sure to install license files
* Wed Jun  6 2018 mcepl@suse.com
- Clean SPEC file
- Switched on tests
- Update to 1.3.6
  * Proper import of load
  * Escaping: replace xml-1.0-illegal characters with question marks
  * ODT merge example
  * Changed the path to save images.
    Now image of the subobject is stored in a folder of subobject
* Thu Aug 24 2017 tbechtold@suse.com
- update to 1.3.5
- convert to singlespec
* Fri Sep 13 2013 os-dev@jacraig.com
- Update to 0.9.6:
  * This maintenance release adds the sources for the man-pages, and replaces
    the thumbnail icon because the original has disappeared from
    http://www.zwahlendesign.ch/en/node/20 along with the license statement.
- Changes from 0.9.5:
  * Added missing license declarations.
- Changes from 0.9.4:
  * This is a patch to fix an issue where chart styles were lost when saving a
    ODT document.
- Change BuildRequires from distribute to setuptools.
- Spec file cleanup:
  * Only add python_sitelib definition if needed and add braces when it is
    used.
* Mon Oct  8 2012 cfarrell@suse.com
- license update: GPL-2.0+ and Apache-2.0
  See setup.py
* Wed Sep 21 2011 saschpe@suse.de
- Fix non-executable scripts
- Removed %%clean section and CFLAGS, not needed
* Thu Mar 31 2011 saschpe@suse.de
- Removed *.egg-info from %%%%files section
* Thu Mar  3 2011 saschpe@suse.de
- Update to 0.9.3:
  * No changelog
- Spec file cleanup:
  * Removed empty lines, fixed indentation and license header
  * No Perl build dependency
* Fri Aug 27 2010 toms@suse.de
- Added .changes file
* Wed Feb 17 2010 cfarrell1980@gmail.com
- Update to 0.9.2
* Tue Nov  3 2009 cfarrell1980@gmail.com
- Update to 0.9.1
* Tue Aug 12 2008 cfarrell1980@gmail.com
- Initial import and build.
- darix suggested to use perl to gather the man files.
